@@ -22,11 +22,7 @@ class Horde_Mapi_MapiTest extends PHPUnit_Framework_TestCase
     public function testFiletimeToUnixTime()
     {
         $data = file_get_contents(__DIR__ . '/fixtures/filetime');
-        try {
-            $this->assertEquals(Horde_Mapi::filetimeToUnixtime($data), 1387818000);
-        } catch (Horde_Mapi_Exception $e) {
-            $this->markTestSkipped("bcmath extension isn't loaded");
-        }
+        $this->assertEquals(Horde_Mapi::filetimeToUnixtime($data), 1387818000);
     }
 
     /**
